==> styled-reboot-4.0.3.tgz: package/README.md <==
[![CircleCI](https://circleci.com/gh/alexruzzarin/styled-reboot.svg?style=svg&circle-token=b24a76575acba70150e3b06340a67d54747643d0)](https://circleci.com/gh/alexruzzarin/styled-reboot)

# styled-reboot
Bootstrap 4 reboot.css for styled-components


[reboot.css from Bootstrap v4](https://github.com/twbs/bootstrap/blob/v4-dev/scss/_reboot.scss) for
[styled-components](https://github.com/styled-components/styled-components).

Also see [styled-reset](https://github.com/zacanger/styled-reset/)
from [Zac Anger](https://github.com/zacanger)
&&
also see [styled-normalize](https://www.npmjs.com/package/styled-normalize)
from [LestaD](https://github.com/LestaD).

--------

## Installation:

`npm i styled-reboot` (use the `-S` flag if you're on npm 4 or earlier).

## Usage with styled-components v4:

```javascript
// global-style.js
import { createGlobalStyle } from 'styled-components';
import reboot from 'styled-reboot';

// Options are, of course, optional, these are the default options
const options = {
  black: '#000',
  fontFamilyBase:
    '-apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, "Helvetica Neue", Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol", "Noto Color Emoji"',
  fontFamilyMonospace:
    'SFMono-Regular, Menlo, Monaco, Consolas, "Liberation Mono", "Courier New", monospace',
  fontSizeBase: '1rem',
  fontWeightBase: 400,
  lineHeightBase: 1.5,
  bodyColor: '#212529',
  bodyBg: '#fff',
  headingsMarginBottom: '0.5rem',
  paragraphMarginBottom: '1rem',
  labelMarginBottom: '0.5rem',
  dtFontWeight: 700,
  linkColor: '#007bff',
  linkDecoration: 'none',
  linkHoverColor: '#0056b3',
  linkHoverDecoration: 'underline',
  tableCellPadding: '0.75rem',
  textMuted: '#6c757d'
};

const rebootCss = reboot(/* options */);

const GlobalStyle = createGlobalStyle`
  ${rebootCss}
  /* other styles */
`

export default GlobalStyle;

// app.js
import GlobalStyle from './global-style';

const App = () => (
  <>
    <GlobalStyle />
    <div>Hi!</div>
  </>
}

export default App;
```

You can also use named imports:

```javascript
// ES Modules
import { reboot } from 'styled-reboot';

// CommonJS
const { reboot } = require('styled-reboot');
```


## Credits

All credit goes to Bootstrap for reboot.css.
Bootstrap is released under the MIT License.

## License:

[MIT](./LICENSE.md)

==> styled-reboot-5.0.0.tgz: package/README.md <==
[![CircleCI](https://circleci.com/gh/alexruzzarin/styled-reboot.svg?style=svg&circle-token=b24a76575acba70150e3b06340a67d54747643d0)](https://circleci.com/gh/alexruzzarin/styled-reboot)

# styled-reboot
Bootstrap 4 reboot.css for styled-components


[reboot.css from Bootstrap v4](https://github.com/twbs/bootstrap/blob/v4-dev/scss/_reboot.scss) for
[styled-components](https://github.com/styled-components/styled-components).

Also see [styled-reset](https://github.com/zacanger/styled-reset/)
from [Zac Anger](https://github.com/zacanger)
&&
also see [styled-normalize](https://www.npmjs.com/package/styled-normalize)
from [LestaD](https://github.com/LestaD).

--------

## Installation:

`npm i styled-reboot`

## Usage with styled-components v4 or v5:

```javascript
// app.js
import * as React from 'react';
import { Reboot } from 'styled-reboot';

const App = () => (
  <>
    <Reboot />
    <div>Hi, I'm an app!</div>
  </>
);

export default App;
```

Or you can create your own global style (Don't forget to create a theme, or extend ours! We provide a few defaults.):

```javascript
// app.js
import React from 'react';
import { createGlobalStyle, ThemeProvider } from 'styled-components';
import { reboot, defaultRebootTheme } from 'styled-reboot';

const GlobalStyle = createGlobalStyle`
  ${reboot}
  /* other styles */
`;

const App = () => (
  <ThemeProvider theme={defaultRebootTheme}>
    <GlobalStyle />
    <div>Hi, I'm an app!</div>
  </ThemeProvider>
};

export default App;
```

## Credits

All credit goes to Bootstrap for reboot.css.
Bootstrap is released under the MIT License.

## License:

[MIT](./LICENSE.md)
